@@ -16,7 +16,7 @@ _MAX_INT = sys.maxint
 _jsonf = path.join(path.split(__file__)[0], 'gamecenter-json', '%s.json.gz')
 _json_base_url = "http://www.nfl.com/liveupdate/game-center/%s/%s_gtd.json"
 
-GameDiff = namedtuple('GameDiff', ['plays', 'players'])
+GameDiff = namedtuple('GameDiff', ['before', 'after', 'plays', 'players'])
 """
 Represents the difference between two points in time of the same game
 in terms of plays and player statistics.
@@ -119,11 +119,10 @@ class GameClock (object):
         self.qtr = qtr
         self.clock = clock
 
-        # Make it easy for comparison.
-        # try:
-        self.__minutes, self.__seconds = map(int, self.clock.split(':'))
-        # except ValueError:
-            # self.__minutes, self.__seconds = 0, 0
+        try:
+            self.__minutes, self.__seconds = map(int, self.clock.split(':'))
+        except ValueError:
+            self.__minutes, self.__seconds = 0, 0
         try:
             self.__qtr = int(self.qtr)
             if self.__qtr >= 3:
@@ -184,6 +183,23 @@ class Game (object):
             return None
         game = object.__new__(cls)
         game.rawData = rawData
+
+        try:
+            if eid is not None:
+                game.eid = eid
+                game.data = json.loads(game.rawData)[game.eid]
+            else:  # For when we have rawData (fpath) and no eid.
+                game.eid = None
+                game.data = json.loads(game.rawData)
+                for k, v in game.data.iteritems():
+                    if isinstance(v, dict):
+                        game.eid = k
+                        game.data = v
+                        break
+                assert game.eid is not None
+        except ValueError:
+            return None
+
         return game
 
     def __init__(self, eid=None, fpath=None):
@@ -201,19 +217,6 @@ class Game (object):
         When the JSON data is written to disk, it is compressed using gzip.
         """
 
-        if eid is not None:
-            self.eid = eid
-            self.data = json.loads(self.rawData)[self.eid]
-        else:  # For when we have rawData (fpath) and no eid.
-            self.eid = None
-            self.data = json.loads(self.rawData)
-            for k, v in self.data.iteritems():
-                if isinstance(v, dict):
-                    self.eid = k
-                    self.data = v
-                    break
-            assert self.eid is not None
-
         # Home and team cumulative statistics.
         self.home = self.data['home']['abbr']
         self.away = self.data['away']['abbr']
@@ -307,29 +310,40 @@ class Game (object):
         game_players = list(self.players)
         play_players = list(self.drives.plays().players())
         max_players = OrderedDict()
-        for pgame in game_players:
-            for pplay in play_players:
-                if pgame.playerid != pplay.playerid:
+
+        # So this is a little tricky. It's possible for a player to have
+        # only statistics at the play level, and therefore not be represented
+        # in the game level statistics. Therefore, we initialize our
+        # max_players with play-by-play stats first. Then go back through
+        # and combine them with available game statistics.
+        for pplay in play_players:
+            newp = nflgame.player.GamePlayerStats(pplay.playerid,
+                                                  pplay.name, pplay.home,
+                                                  pplay.team)
+            maxstats = {}
+            for stat, val in pplay._stats.iteritems():
+                maxstats[stat] = val
+
+            newp._overwrite_stats(maxstats)
+            max_players[pplay.playerid] = newp
+
+        for newp in max_players.itervalues():
+            for pgame in game_players:
+                if pgame.playerid != newp.playerid:
                     continue
 
-                newp = nflgame.player.GamePlayerStats(pgame.playerid,
-                                                      pgame.name,
-                                                      pgame.home)
                 maxstats = {}
                 for stat, val in pgame._stats.iteritems():
-                    maxstats[stat] = val
-                for stat, val in pplay._stats.iteritems():
-                    maxstats[stat] = max([val, maxstats.get(stat, -_MAX_INT)])
-
-                newp._add_stats(maxstats)
-                max_players[pgame.playerid] = newp
+                    maxstats[stat] = max([val,
+                                          newp._stats.get(stat, -_MAX_INT)])
 
+                newp._overwrite_stats(maxstats)
                 break
         return nflgame.seq.GenPlayerStats(max_players)
 
     def __getattr__(self, name):
         if name == 'players':
-            self.__players = _json_game_player_stats(self.data)
+            self.__players = _json_game_player_stats(self, self.data)
             self.players = nflgame.seq.GenPlayerStats(self.__players)
             return self.players
         if name == 'drives':
@@ -353,14 +367,7 @@ def diff(before, after):
 
     This is useful for sending alerts where you're guaranteed to see each
     play statistic only once (assuming NFL.com behaves itself).
-
-    XXX: There is an assertion that requires after's game clock be the same
-    or later than before's game clock. This may need to be removed if NFL.com
-    allows its game clock to be rolled back due to corrections from refs.
     """
-    assert after.time >= before.time, \
-        'When diffing two games, "after" (%s) must be later or the ' \
-        'same time as "before" (%s).' % (after.time, before.time)
     assert after.eid == before.eid
 
     plays = []
@@ -376,8 +383,8 @@ def diff(before, after):
     # updated (late call? play review? etc.)
     # Thus, we do a diff on the play statistics for player data too.
     _players = OrderedDict()
-    after_players = list(after.drives.players())
-    before_players = list(before.drives.players())
+    after_players = list(after.max_player_stats())
+    before_players = list(before.max_player_stats())
     for aplayer in after_players:
         has_before = False
         for bplayer in before_players:
@@ -390,7 +397,7 @@ def diff(before, after):
             _players[aplayer.playerid] = aplayer
     players = nflgame.seq.GenPlayerStats(_players)
 
-    return GameDiff(plays=plays, players=players)
+    return GameDiff(before=before, after=after, plays=plays, players=players)
 
 
 class Drive (object):
@@ -498,6 +505,7 @@ class Play (object):
         self.down = int(data['down'])
         self.yards_togo = int(data['ydstogo'])
         self.touchdown = 'touchdown' in self.desc.lower()
+        self._stats = {}
 
         if not self.team:
             self.time, self.yardline = None, None
@@ -514,7 +522,9 @@ class Play (object):
                 statvals = nflgame.statmap.values(info['statId'],
                                                   info['yards'])
                 for k, v in statvals.iteritems():
-                    self.__dict__[k] = self.__dict__.get(k, 0) + v
+                    v = self.__dict__.get(k, 0) + v
+                    self.__dict__[k] = v
+                    self._stats[k] = v
 
         # Load the sequence of "events" in a play into a list of dictionaries.
         self.events = _json_play_events(data['players'])
@@ -532,6 +542,7 @@ class Play (object):
                 # data is from the perspective of the play. i.e., there
                 # is one assisted tackle rather than two.
                 self.__dict__[k] = v
+                self._stats[k] = v
 
     def has_player(self, playerid):
         """Whether a player with id playerid participated in this play."""
@@ -631,9 +642,13 @@ def _json_play_players(play, data):
                 continue
             if playerid not in players:
                 home = play.drive.game.is_home(info['clubcode'])
+                if home:
+                    team_name = play.drive.game.home
+                else:
+                    team_name = play.drive.game.away
                 stats = nflgame.player.PlayPlayerStats(playerid,
                                                        info['playerName'],
-                                                       home)
+                                                       home, team_name)
                 players[playerid] = stats
             statvals = nflgame.statmap.values(info['statId'], info['yards'])
             players[playerid]._add_stats(statvals)
@@ -657,7 +672,7 @@ def _json_play_events(data):
     return [t[1] for t in sorted(temp, key=lambda t: t[0])]
 
 
-def _json_game_player_stats(data):
+def _json_game_player_stats(game, data):
     """
     Parses the 'home' and 'away' team stats and returns an OrderedDict
     mapping player id to their total game statistics as instances of
@@ -676,9 +691,14 @@ def _json_game_player_stats(data):
                     stats['%s_%s' % (category, k)] = v
                 if pid not in players:
                     home = team == 'home'
+                    if home:
+                        team_name = game.home
+                    else:
+                        team_name = game.away
                     players[pid] = nflgame.player.GamePlayerStats(pid,
                                                                   raw['name'],
-                                                                  home)
+                                                                  home,
+                                                                  team_name)
                 players[pid]._add_stats(stats)
     return players
 
