@@ -97,29 +97,27 @@ class PlayerStats (object):
         if 'passing_yds' in player.__dict__:
             # Do something with player.passing_yds
     """
-    def __init__(self, playerid, name, home):
+    def __init__(self, playerid, name, home, team):
         """
         Create a new Player instance with the player id (from NFL.com's
         GameCenter), the player's name (e.g., "T.Brady") and whether the
         player is playing in a home game or not.
         """
         self.playerid = playerid
-        self.player = None
         self.name = name
         self.home = home
+        self.team = team
         self._stats = OrderedDict()
+
+        self.player = None
         if self.playerid in nflgame.players:
             self.player = nflgame.players[self.playerid]
 
     def has_cat(self, cat):
-        return self.__dict__.get(cat, False)
-
-    def __refresh_categories(self):
-        for cat in nflgame.statmap.categories:
-            for f in self.__dict__:
-                if f.startswith(cat):
-                    self.__dict__[cat] = True
-                    break
+        for f in self._stats:
+            if f.startswith(cat):
+                return True
+        return False
 
     @property
     def tds(self):
@@ -183,7 +181,11 @@ class PlayerStats (object):
         for k, v in stats.iteritems():
             self.__dict__[k] = self.__dict__.get(k, 0) + v
             self._stats[k] = self.__dict__[k]
-        self.__refresh_categories()
+
+    def _overwrite_stats(self, stats):
+        for k, v in stats.iteritems():
+            self.__dict__[k] = v
+            self._stats[k] = self.__dict__[k]
 
     def __str__(self):
         """
@@ -203,12 +205,16 @@ class PlayerStats (object):
         sums of all statistical values.
 
         Note that as soon as two players have been added, the 'home' property
-        becomes undefined.
+        becomes undefined if the two operands have different values of 'home'.
         """
         assert self.playerid == other.playerid
         assert type(self) == type(other)
 
-        new_player = self.__class__(self.playerid, self.name, None)
+        if self.home != other.home:
+            home = None
+        else:
+            home = self.home
+        new_player = self.__class__(self.playerid, self.name, home, self.team)
         new_player._add_stats(self._stats)
         new_player._add_stats(other._stats)
 
@@ -250,8 +256,8 @@ class PlayerStats (object):
 
 
 class GamePlayerStats (PlayerStats):
-    def __init__(self, playerid, name, home):
-        super(GamePlayerStats, self).__init__(playerid, name, home)
+    def __init__(self, playerid, name, home, team):
+        super(GamePlayerStats, self).__init__(playerid, name, home, team)
         self.games = 1
 
     def __add__(self, other):
